@@ -1,15 +1,11 @@
 package Parse::Keyword;
-BEGIN {
-  $Parse::Keyword::AUTHORITY = 'cpan:DOY';
-}
-{
-  $Parse::Keyword::VERSION = '0.08';
-}
 use strict;
 use warnings;
 use 5.014;
 # ABSTRACT: DEPRECATED: write syntax extensions in perl
 
+our $VERSION = '0.09';
+
 use Devel::CallParser;
 use XSLoader;
 
@@ -63,13 +59,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Parse::Keyword - DEPRECATED: write syntax extensions in perl
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -209,9 +207,6 @@ This module doesn't yet work with lexical subs, such as via
 L<Exporter::Lexical>. This will hopefully be fixed in the future, but will
 likely require modifications to perl.
 
-Please report any bugs to GitHub Issues at
-L<https://github.com/doy/parse-keyword/issues>.
-
 =head1 SEE ALSO
 
 L<Devel::CallParser>
@@ -240,11 +235,7 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Parse-Keyword>
 
 =item * Github
 
-L<https://github.com/doy/parse-keyword>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Parse-Keyword>
+L<https://github.com/haarg/Parse-Keyword>
 
 =back
 
